<?php
/**
 * Wall Decor Wallpaper Theme Customizer
 *
 * @package Wall Decor Wallpaper
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function wall_decor_wallpaper_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'wall_decor_wallpaper_custom_controls' );

function wall_decor_wallpaper_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.logo .site-title a',
	 	'render_callback' => 'wall_decor_wallpaper_Customize_partial_blogname',
	));

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => 'p.site-description',
		'render_callback' => 'wall_decor_wallpaper_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'wall_decor_wallpaper_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'Homepage Settings', 'wall-decor-wallpaper' ),
		'priority' => 10,
	));

   	// Header Background color
	$wp_customize->add_setting('wall_decor_wallpaper_header_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_header_background_color', array(
		'label'    => __('Header Background Color', 'wall-decor-wallpaper'),
		'section'  => 'header_image',
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh', 
	  'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','wall-decor-wallpaper'),
		'section' => 'header_image',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'wall-decor-wallpaper' ),
			'center top'   => esc_html__( 'Top', 'wall-decor-wallpaper' ),
			'right top'   => esc_html__( 'Top Right', 'wall-decor-wallpaper' ),
			'left center'   => esc_html__( 'Left', 'wall-decor-wallpaper' ),
			'center center'   => esc_html__( 'Center', 'wall-decor-wallpaper' ),
			'right center'   => esc_html__( 'Right', 'wall-decor-wallpaper' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'wall-decor-wallpaper' ),
			'center bottom'   => esc_html__( 'Bottom', 'wall-decor-wallpaper' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'wall-decor-wallpaper' ),
		),
	));

	//Menus Settings
	$wp_customize->add_section( 'wall_decor_wallpaper_menu_section' , array(
    	'title' => __( 'Menus Settings', 'wall-decor-wallpaper' ),
		'panel' => 'wall_decor_wallpaper_panel_id'
	) );

	$wp_customize->add_setting('wall_decor_wallpaper_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_menu_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_navigation_menu_font_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_menu_section',
        'choices' => array(
        	'100' => __('100','wall-decor-wallpaper'),
            '200' => __('200','wall-decor-wallpaper'),
            '300' => __('300','wall-decor-wallpaper'),
            '400' => __('400','wall-decor-wallpaper'),
            '500' => __('500','wall-decor-wallpaper'),
            '600' => __('600','wall-decor-wallpaper'),
            '700' => __('700','wall-decor-wallpaper'),
            '800' => __('800','wall-decor-wallpaper'),
            '900' => __('900','wall-decor-wallpaper'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('wall_decor_wallpaper_menu_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menu Text Transform','wall-decor-wallpaper'),
		'choices' => array(
            'Uppercase' => __('Uppercase','wall-decor-wallpaper'),
            'Capitalize' => __('Capitalize','wall-decor-wallpaper'),
            'Lowercase' => __('Lowercase','wall-decor-wallpaper'),
        ),
		'section'=> 'wall_decor_wallpaper_menu_section',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_menus_item_style',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_menus_item_style',array(
        'type' => 'select',
        'section' => 'wall_decor_wallpaper_menu_section',
		'label' => __('Menu Item Hover Style','wall-decor-wallpaper'),
		'choices' => array(
            'None' => __('None','wall-decor-wallpaper'),
            'Zoom In' => __('Zoom In','wall-decor-wallpaper'),
        ),
	) );

	$wp_customize->add_setting('wall_decor_wallpaper_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_header_menus_color', array(
		'label'    => __('Menus Color', 'wall-decor-wallpaper'),
		'section'  => 'wall_decor_wallpaper_menu_section',
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'wall-decor-wallpaper'),
		'section'  => 'wall_decor_wallpaper_menu_section',
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'wall-decor-wallpaper'),
		'section'  => 'wall_decor_wallpaper_menu_section',
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'wall-decor-wallpaper'),
		'section'  => 'wall_decor_wallpaper_menu_section',
	)));

	//Topbar
	$wp_customize->add_section( 'wall_decor_wallpaper_header_section' , array(
  		'title' => __( 'Header Section', 'wall-decor-wallpaper' ),
		'panel' => 'wall_decor_wallpaper_panel_id'
	) );

	//Sticky Header
	$wp_customize->add_setting( 'wall_decor_wallpaper_sticky_header',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	) );
	$wp_customize->add_control( new wall_decor_wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_sticky_header',array(
	  'label' => esc_html__( 'Sticky Header','wall-decor-wallpaper' ),
	  'section' => 'wall_decor_wallpaper_header_section'
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_sticky_header_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_sticky_header_padding',array(
		'label'	=> __('Sticky Header Padding','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_header_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'wall_decor_wallpaper_topbar_hide_show',array(
    	'default' => 0,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_topbar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Header','wall-decor-wallpaper' ),
      	'section' => 'wall_decor_wallpaper_header_section'
    )));

	$wp_customize->add_setting('wall_decor_wallpaper_topbar_text1',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_topbar_text1',array(
		'label'	=> esc_html__('Add Topbar Text 1','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Hooked on your sale | Upto 40% off..', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_header_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_topbar_text2',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_topbar_text2',array(
		'label'	=> esc_html__('Add Topbar Text 2','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Extra Cashback on Your First order', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_header_section',
		'type'=> 'text'
	));

	// Middle header

	$wp_customize->add_setting( 'wall_decor_wallpaper_my_account_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_my_account_hide_show',
       array(
		'label' => esc_html__( 'Show / Hide My Account','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_header_section'
    )));

    $wp_customize->add_setting( 'wall_decor_wallpaper_cart_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_cart_hide_show',
       array(
		'label' => esc_html__( 'Show / Hide Cart','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_header_section'
    )));

    $wp_customize->add_setting( 'wall_decor_wallpaper_wishlist_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_wishlist_hide_show',
       array(
		'label' => esc_html__( 'Show / Hide Wishlist','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_header_section'
    )));

	//Slider
	$wp_customize->add_section( 'wall_decor_wallpaper_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'wall-decor-wallpaper' ),
  		'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/wall-decor-wordpress-theme/">GET PRO</a>','wall-decor-wallpaper'),
		'panel' => 'wall_decor_wallpaper_panel_id'
	) );

	$wp_customize->add_setting( 'wall_decor_wallpaper_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','wall-decor-wallpaper' ),
      'section' => 'wall_decor_wallpaper_slidersettings'
    )));

	$wp_customize->add_setting('wall_decor_wallpaper_slider_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_slider_title',array(
		'label'	=> __('Add Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( 'NEW ARRIVALS', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_slidersettings',
		'type'=> 'text'
	));

  $wp_customize->add_setting('wall_decor_wallpaper_slider_type',array(
    'default' => 'Default slider',
    'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	) );
	$wp_customize->add_control('wall_decor_wallpaper_slider_type', array(
    'type' => 'select',
    'label' => __('Slider Type','wall-decor-wallpaper'),
    'section' => 'wall_decor_wallpaper_slidersettings',
    'choices' => array(
        'Default slider' => __('Default slider','wall-decor-wallpaper'),
        'Advance slider' => __('Advance slider','wall-decor-wallpaper'),
        ),
	));

	$wp_customize->add_setting('wall_decor_wallpaper_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_slidersettings',
		'type'=> 'text',
		'active_callback' => 'wall_decor_wallpaper_advance_slider'
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'wall_decor_wallpaper_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'wall_decor_wallpaper_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'wall_decor_wallpaper_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'wall-decor-wallpaper' ),
			'description' => __('Slider image size (1400 x 550)','wall-decor-wallpaper'),
			'section'  => 'wall_decor_wallpaper_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'wall_decor_wallpaper_default_slider'
		) );
	}

   	$wp_customize->add_setting( 'wall_decor_wallpaper_slider_icon_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_slider_icon_hide_show',array(
      'label' => esc_html__( 'Show / Hide Social icons','wall-decor-wallpaper' ),
      'section' => 'wall_decor_wallpaper_slidersettings',
      'active_callback' => 'wall_decor_wallpaper_default_slider'
    )));

	$wp_customize->add_setting('wall_decor_wallpaper_banner_button_label',array(
		'default' => 'Shop Now',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_banner_button_label',array(
		'label' => __('Button','wall-decor-wallpaper'),
		'section' => 'wall_decor_wallpaper_slidersettings',
		'setting' => 'wall_decor_wallpaper_banner_button_label',
		'type' => 'text',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	));
	$wp_customize->add_setting('wall_decor_wallpaper_top_button_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));

	$wp_customize->add_control('wall_decor_wallpaper_top_button_url',array(
		'label'	=> __('Add Button URL','wall-decor-wallpaper'),
		'section'	=> 'wall_decor_wallpaper_slidersettings',
		'setting'	=> 'wall_decor_wallpaper_top_button_url',
		'type'	=> 'url',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('wall_decor_wallpaper_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'wall_decor_wallpaper_customize_partial_wall_decor_wallpaper_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'wall_decor_wallpaper_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'wall_decor_wallpaper_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'wall_decor_wallpaper_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'wall-decor-wallpaper' ),
			'description' => __('Slider image size (1400 x 550)','wall-decor-wallpaper'),
			'section'  => 'wall_decor_wallpaper_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'wall_decor_wallpaper_default_slider'
		) );
	}

	//content layout
	$wp_customize->add_setting('wall_decor_wallpaper_slider_content_option',array(
        'default' => 'Left',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Image_Radio_Control($wp_customize, 'wall_decor_wallpaper_slider_content_option', array(
        'type' => 'select',
        'label' => esc_html__('Slider Content Layouts','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ),'active_callback' => 'wall_decor_wallpaper_default_slider'
    )));

    //Slider content padding
    $wp_customize->add_setting('wall_decor_wallpaper_slider_content_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_slider_content_padding_top_bottom',array(
		'label'	=> __('Slider Content Padding Top Bottom','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in %. Example:20%','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_slidersettings',
		'type'=> 'text',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_slider_content_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_slider_content_padding_left_right',array(
		'label'	=> __('Slider Content Padding Left Right','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in %. Example:20%','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_slidersettings',
		'type'=> 'text',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	));

    //Slider excerpt
	$wp_customize->add_setting( 'wall_decor_wallpaper_slider_excerpt_number', array(
		'default'              => 25,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_slidersettings',
		'type'        => 'range',
		'settings'    => 'wall_decor_wallpaper_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),'active_callback' => 'wall_decor_wallpaper_default_slider'
	) );


	$wp_customize->add_setting( 'wall_decor_wallpaper_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','wall-decor-wallpaper'),
		'section' => 'wall_decor_wallpaper_slidersettings',
		'type'  => 'text',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('wall_decor_wallpaper_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_slider_height',array(
		'label'	=> __('Slider Height','wall-decor-wallpaper'),
		'description'	=> __('Specify the slider height (px).','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_slidersettings',
		'type'=> 'text',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	));

	//Opacity
	$wp_customize->add_setting('wall_decor_wallpaper_slider_opacity_color',array(
      'default'              => 0.8,
      'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));

	$wp_customize->add_control( 'wall_decor_wallpaper_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_slidersettings',
		'type'        => 'select',
		'settings'    => 'wall_decor_wallpaper_slider_opacity_color',
		'choices' => array(
	      '0' =>  esc_attr('0','wall-decor-wallpaper'),
	      '0.1' =>  esc_attr('0.1','wall-decor-wallpaper'),
	      '0.2' =>  esc_attr('0.2','wall-decor-wallpaper'),
	      '0.3' =>  esc_attr('0.3','wall-decor-wallpaper'),
	      '0.4' =>  esc_attr('0.4','wall-decor-wallpaper'),
	      '0.5' =>  esc_attr('0.5','wall-decor-wallpaper'),
	      '0.6' =>  esc_attr('0.6','wall-decor-wallpaper'),
	      '0.7' =>  esc_attr('0.7','wall-decor-wallpaper'),
	      '0.8' =>  esc_attr('0.8','wall-decor-wallpaper'),
	      '0.9' =>  esc_attr('0.9','wall-decor-wallpaper')
	),'active_callback' => 'wall_decor_wallpaper_default_slider'
	));

	$wp_customize->add_setting( 'wall_decor_wallpaper_slider_image_overlay',array(
    	'default' => '#000',
    	'transport' => 'refresh',
    	'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
   ));
   $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_slider_image_overlay',array(
      	'label' => esc_html__( 'Slider Image Overlay','wall-decor-wallpaper' ),
      	'section' => 'wall_decor_wallpaper_slidersettings',
      	'active_callback' => 'wall_decor_wallpaper_default_slider'
   )));

   $wp_customize->add_setting('wall_decor_wallpaper_slider_image_overlay_color', array(
		'default'           => 1,
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'wall-decor-wallpaper'),
		'section'  => 'wall_decor_wallpaper_slidersettings',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	)));

	$wp_customize->add_setting( 'wall_decor_wallpaper_slider_arrow_hide_show',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	));
	$wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_slider_arrow_hide_show',array(
		'label' => esc_html__( 'Show / Hide Slider Arrows','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_slidersettings',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_slider_prev_icon',array(
		'default'	=> 'fas fa-angle-left',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_slider_prev_icon',array(
		'label'	=> __('Add Slider Prev Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_slidersettings',
		'setting'	=> 'wall_decor_wallpaper_slider_prev_icon',
		'type'		=> 'icon',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_slider_next_icon',array(
		'default'	=> 'fas fa-angle-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_slider_next_icon',array(
		'label'	=> __('Add Slider Next Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_slidersettings',
		'setting'	=> 'wall_decor_wallpaper_slider_next_icon',
		'type'		=> 'icon',
		'active_callback' => 'wall_decor_wallpaper_default_slider'
	)));

	//feature Section
	$wp_customize->add_section('wall_decor_wallpaper_feature_section', array(
		'title'       => __('Feature Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_feature_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_feature_text',array(
		'description' => __('<p>1. More options for feature section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for feature section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_feature_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_feature_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_feature_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_feature_section',
		'type'=> 'hidden'
	));

	//about us Section
	$wp_customize->add_section('wall_decor_wallpaper_about_us_section', array(
		'title'       => __('About Us Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_about_us_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_about_us_text',array(
		'description' => __('<p>1. More options for about us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for about us section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_about_us_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_about_us_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_about_us_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_about_us_section',
		'type'=> 'hidden'
	));

	//our categories Section
	$wp_customize->add_section('wall_decor_wallpaper_our_categories_section', array(
		'title'       => __('Our Categories Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_our_categories_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_our_categories_text',array(
		'description' => __('<p>1. More options for our categories section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for our categories section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_our_categories_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_our_categories_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_our_categories_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_our_categories_section',
		'type'=> 'hidden'
	));

	// Products Section
	$wp_customize->add_section( 'wall_decor_wallpaper_product_section' , array(
    	'title'      => __( 'Products Section', 'wall-decor-wallpaper' ),
		'priority'   => null,
		'description' => __('For more options of Products section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/wall-decor-wordpress-theme/">GET PRO</a>','wall-decor-wallpaper'),
		'panel' => 'wall_decor_wallpaper_panel_id'
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'wall_decor_wallpaper_product_settings', array(
		'selector' => '.main-product-section h3',
		'render_callback' => 'wall_decor_wallpaper_customize_partial_wall_decor_wallpaper_product_settings',
	));

	$wp_customize->add_setting( 'wall_decor_wallpaper_product_hide_show',array(
	    'default' => 0,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	));
	$wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_product_hide_show',array(
		'label' => esc_html__( 'Show / Hide Product Section','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_product_section'
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_product_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_product_title',array(
		'label'	=> __('Add Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( 'NEW DESIGN FOR YOUR WALL', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_product_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_product_heading_product',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_product_heading_product',array(
		'label'	=> __('Add Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( 'NEW ARRIVALS', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_product_section',
		'type'=> 'text'
	));

	$args = array(
		'type'         => 'product',
		'child_of'     => 0,
		'parent'       => '',
		'orderby'      => 'term_group',
		'order'        => 'ASC',
		'hide_empty'   => false,
		'hierarchical' => 1,
		'number'       => '',
		'taxonomy'     => 'product_cat',
		'pad_counts'   => false
	);
 	$categories = get_categories( $args );
	$cat_posts = array();
	$i = 0;
	$cat_posts[]='Select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('wall_decor_wallpaper_product_settings',array(
		'default'	=> 'select',
		'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices',
	));
	$wp_customize->add_control('wall_decor_wallpaper_product_settings',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Products','wall-decor-wallpaper'),
		'section' => 'wall_decor_wallpaper_product_section',
	));

	//top selling Section
	$wp_customize->add_section('wall_decor_wallpaper_top_selling_section', array(
		'title'       => __('Top Selling Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_top_selling_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_top_selling_text',array(
		'description' => __('<p>1. More options for top selling section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for top selling section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_top_selling_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_top_selling_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_top_selling_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_top_selling_section',
		'type'=> 'hidden'
	));

	//best deal Section
	$wp_customize->add_section('wall_decor_wallpaper_best_deal_section', array(
		'title'       => __('Best Deal Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_best_deal_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_best_deal_text',array(
		'description' => __('<p>1. More options for best deal section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for best deal section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_best_deal_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_best_deal_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_best_deal_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_best_deal_section',
		'type'=> 'hidden'
	));

	//gallary Section
	$wp_customize->add_section('wall_decor_wallpaper_gallary_section', array(
		'title'       => __('Gallary Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_gallary_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_gallary_text',array(
		'description' => __('<p>1. More options for gallary section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for gallary section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_gallary_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_gallary_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_gallary_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_gallary_section',
		'type'=> 'hidden'
	));

	//discount Section
	$wp_customize->add_section('wall_decor_wallpaper_discount_section', array(
		'title'       => __('Discount Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_discount_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_discount_text',array(
		'description' => __('<p>1. More options for discount section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for discount section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_discount_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_discount_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_discount_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_discount_section',
		'type'=> 'hidden'
	));

	//video sec Section
	$wp_customize->add_section('wall_decor_wallpaper_video_slider_content_section', array(
		'title'       => __('Video Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_video_slider_content_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_video_slider_content_text',array(
		'description' => __('<p>1. More options for video section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for video section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_video_slider_content_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_video_slider_content_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_video_slider_content_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_video_slider_content_section',
		'type'=> 'hidden'
	));

	//best styles Section
	$wp_customize->add_section('wall_decor_wallpaper_best_styles_section', array(
		'title'       => __('Best Styles Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_best_styles_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_best_styles_text',array(
		'description' => __('<p>1. More options for best styles section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for best styles section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_best_styles_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_best_styles_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_best_styles_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_best_styles_section',
		'type'=> 'hidden'
	));

	//testimonial Section
	$wp_customize->add_section('wall_decor_wallpaper_testimonial_section', array(
		'title'       => __('Testimonial Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_testimonial_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_testimonial_text',array(
		'description' => __('<p>1. More options for testimonial section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonial section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_testimonial_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_testimonial_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_testimonial_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_testimonial_section',
		'type'=> 'hidden'
	));

	//latest news Section
	$wp_customize->add_section('wall_decor_wallpaper_latest_news_section', array(
		'title'       => __('Latest News Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_latest_news_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_latest_news_text',array(
		'description' => __('<p>1. More options for latest news section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for latest news section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_latest_news_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_latest_news_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_latest_news_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_latest_news_section',
		'type'=> 'hidden'
	));

	//newsletter Section
	$wp_customize->add_section('wall_decor_wallpaper_newsletter_section', array(
		'title'       => __('Newsletter Section', 'wall-decor-wallpaper'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','wall-decor-wallpaper'),
		'priority'    => null,
		'panel'       => 'wall_decor_wallpaper_panel_id',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_newsletter_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_newsletter_text',array(
		'description' => __('<p>1. More options for newsletter section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for newsletter section.</p>','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_newsletter_section',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_newsletter_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_newsletter_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=wall_decor_wallpaper_guide') ." '>More Info</a>",
		'section'=> 'wall_decor_wallpaper_newsletter_section',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('wall_decor_wallpaper_footer',array(
		'title'	=> esc_html__('Footer Settings','wall-decor-wallpaper'),
		'description' => __('For more options of footer section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/wall-decor-wordpress-theme/">GET PRO</a>','wall-decor-wallpaper'),
		'panel' => 'wall_decor_wallpaper_panel_id',
	));

  $wp_customize->add_setting( 'wall_decor_wallpaper_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
  ));
  $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_footer_hide_show',array(
    'label' => esc_html__( 'Show / Hide Footer','wall-decor-wallpaper' ),
    'section' => 'wall_decor_wallpaper_footer'
  )));

	// font size
	$wp_customize->add_setting('wall_decor_wallpaper_button_footer_font_size',array(
		'default'=> 30,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','wall-decor-wallpaper'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'wall_decor_wallpaper_footer',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','wall-decor-wallpaper'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'wall_decor_wallpaper_footer',
	));

	// text trasform
	$wp_customize->add_setting('wall_decor_wallpaper_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','wall-decor-wallpaper'),
		'choices' => array(
      'Uppercase' => __('Uppercase','wall-decor-wallpaper'),
      'Capitalize' => __('Capitalize','wall-decor-wallpaper'),
      'Lowercase' => __('Lowercase','wall-decor-wallpaper'),
    ),
		'section'=> 'wall_decor_wallpaper_footer',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_footer_heading_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_footer',
        'choices' => array(
        	'100' => __('100','wall-decor-wallpaper'),
            '200' => __('200','wall-decor-wallpaper'),
            '300' => __('300','wall-decor-wallpaper'),
            '400' => __('400','wall-decor-wallpaper'),
            '500' => __('500','wall-decor-wallpaper'),
            '600' => __('600','wall-decor-wallpaper'),
            '700' => __('700','wall-decor-wallpaper'),
            '800' => __('800','wall-decor-wallpaper'),
            '900' => __('900','wall-decor-wallpaper'),
        ),
	) );

  $wp_customize->add_setting('wall_decor_wallpaper_footer_template',array(
      'default'	=> esc_html('wall_decor_wallpaper-footer-one'),
      'sanitize_callback'	=> 'wall_decor_wallpaper_sanitize_choices'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_footer_template',array(
          'label'	=> esc_html__('Footer style','wall-decor-wallpaper'),
          'section'	=> 'wall_decor_wallpaper_footer',
          'setting'	=> 'wall_decor_wallpaper_footer_template',
          'type' => 'select',
          'choices' => array(
              'wall_decor_wallpaper-footer-one' => esc_html__('Style 1', 'wall-decor-wallpaper'),
              'wall_decor_wallpaper-footer-two' => esc_html__('Style 2', 'wall-decor-wallpaper'),
              'wall_decor_wallpaper-footer-three' => esc_html__('Style 3', 'wall-decor-wallpaper'),
              'wall_decor_wallpaper-footer-four' => esc_html__('Style 4', 'wall-decor-wallpaper'),
              'wall_decor_wallpaper-footer-five' => esc_html__('Style 5', 'wall-decor-wallpaper'),
              )
  ));
  
	$wp_customize->add_setting('wall_decor_wallpaper_footer_background_color', array(
		'default'           => '#151821',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_footer_background_color', array(
		'label'    => __('Footer Background Color', 'wall-decor-wallpaper'),
		'section'  => 'wall_decor_wallpaper_footer',
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'wall_decor_wallpaper_footer_background_image',array(
      'label' => __('Footer Background Image','wall-decor-wallpaper'),
      'section' => 'wall_decor_wallpaper_footer'
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','wall-decor-wallpaper'),
		'section' => 'wall_decor_wallpaper_footer',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'wall-decor-wallpaper' ),
			'center top'   => esc_html__( 'Top', 'wall-decor-wallpaper' ),
			'right top'   => esc_html__( 'Top Right', 'wall-decor-wallpaper' ),
			'left center'   => esc_html__( 'Left', 'wall-decor-wallpaper' ),
			'center center'   => esc_html__( 'Center', 'wall-decor-wallpaper' ),
			'right center'   => esc_html__( 'Right', 'wall-decor-wallpaper' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'wall-decor-wallpaper' ),
			'center bottom'   => esc_html__( 'Bottom', 'wall-decor-wallpaper' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'wall-decor-wallpaper' ),
		),
	));

  // Footer
  $wp_customize->add_setting('wall_decor_wallpaper_img_footer',array(
    'default'=> 'scroll',
    'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_img_footer',array(
    'type' => 'select',
    'label' => __('Footer Background Attatchment','wall-decor-wallpaper'),
    'choices' => array(
      'fixed' => __('fixed','wall-decor-wallpaper'),
      'scroll' => __('scroll','wall-decor-wallpaper'),
    ),
    'section'=> 'wall_decor_wallpaper_footer',
  ));

  // footer padding
  $wp_customize->add_setting('wall_decor_wallpaper_footer_padding',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_footer_padding',array(
    'label' => __('Footer Top Bottom Padding','wall-decor-wallpaper'),
    'description' => __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
    'input_attrs' => array(
      'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
    ),
    'section'=> 'wall_decor_wallpaper_footer',
    'type'=> 'text'
  ));

  $wp_customize->add_setting('wall_decor_wallpaper_footer_widgets_heading',array(
    'default' => 'Left',
    'transport' => 'refresh',
    'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_footer_widgets_heading',array(
    'type' => 'select',
    'label' => __('Footer Widget Heading','wall-decor-wallpaper'),
    'section' => 'wall_decor_wallpaper_footer',
    'choices' => array(
      'Left' => __('Left','wall-decor-wallpaper'),
      'Center' => __('Center','wall-decor-wallpaper'),
      'Right' => __('Right','wall-decor-wallpaper')
    ),
  ) );

  $wp_customize->add_setting('wall_decor_wallpaper_footer_widgets_content',array(
    'default' => 'Left',
    'transport' => 'refresh',
    'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_footer_widgets_content',array(
    'type' => 'select',
    'label' => __('Footer Widget Content','wall-decor-wallpaper'),
    'section' => 'wall_decor_wallpaper_footer',
    'choices' => array(
      'Left' => __('Left','wall-decor-wallpaper'),
      'Center' => __('Center','wall-decor-wallpaper'),
      'Right' => __('Right','wall-decor-wallpaper')
    ),
  ) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('wall_decor_wallpaper_footer_text', array(
		'selector' => '.copyright p',
		'render_callback' => 'wall_decor_wallpaper_Customize_partial_wall_decor_wallpaper_footer_text',
	));

  $wp_customize->add_setting( 'wall_decor_wallpaper_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
  ));
  $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_copyright_hide_show',array(
    'label' => esc_html__( 'Show / Hide Copyright','wall-decor-wallpaper' ),
    'section' => 'wall_decor_wallpaper_footer'
  )));

	$wp_customize->add_setting('wall_decor_wallpaper_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_footer_text',array(
		'label'	=> esc_html__('Copyright Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2023, .....', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_footer',
		'type'=> 'text'
	));

  $wp_customize->add_setting('wall_decor_wallpaper_copyright_background_color', array(
    'default'           => '#d9a95b',
    'sanitize_callback' => 'sanitize_hex_color',
  ));
  $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_copyright_background_color', array(
    'label'    => __('Copyright Background Color', 'wall-decor-wallpaper'),
    'section'  => 'wall_decor_wallpaper_footer',
  )));

  $wp_customize->add_setting('wall_decor_wallpaper_copyright_font_size',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_copyright_font_size',array(
    'label' => __('Copyright Font Size','wall-decor-wallpaper'),
    'description' => __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
    'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
    'section'=> 'wall_decor_wallpaper_footer',
    'type'=> 'text'
  ));

	$wp_customize->add_setting('wall_decor_wallpaper_copyright_alingment',array(
    'default' => 'center',
    'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Image_Radio_Control($wp_customize, 'wall_decor_wallpaper_copyright_alingment', array(
    'type' => 'select',
    'label' => esc_html__('Copyright Alignment','wall-decor-wallpaper'),
    'section' => 'wall_decor_wallpaper_footer',
    'settings' => 'wall_decor_wallpaper_copyright_alingment',
    'choices' => array(
        'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
        'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
        'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
  ))));

  $wp_customize->add_setting( 'wall_decor_wallpaper_hide_show_scroll',array(
  	'default' => 1,
  	'transport' => 'refresh',
  	'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
  ));
  $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_hide_show_scroll',array(
  	'label' => esc_html__( 'Show / Hide Scroll to Top','wall-decor-wallpaper' ),
  	'section' => 'wall_decor_wallpaper_footer'
  )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('wall_decor_wallpaper_scroll_to_top_icon', array(
		'selector' => '.scrollup i',
		'render_callback' => 'wall_decor_wallpaper_Customize_partial_wall_decor_wallpaper_scroll_to_top_icon',
	));

  $wp_customize->add_setting('wall_decor_wallpaper_scroll_top_icon',array(
    'default' => 'fas fa-long-arrow-alt-up',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser($wp_customize,'wall_decor_wallpaper_scroll_top_icon',array(
    'label' => __('Add Scroll to Top Icon','wall-decor-wallpaper'),
    'transport' => 'refresh',
    'section' => 'wall_decor_wallpaper_footer',
    'setting' => 'wall_decor_wallpaper_scroll_top_icon',
    'type'    => 'icon'
  )));

  $wp_customize->add_setting('wall_decor_wallpaper_scroll_to_top_font_size',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_scroll_to_top_font_size',array(
    'label' => __('Icon Font Size','wall-decor-wallpaper'),
    'description' => __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
    'input_attrs' => array(
      'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
    ),
    'section'=> 'wall_decor_wallpaper_footer',
    'type'=> 'text'
  ));

  $wp_customize->add_setting('wall_decor_wallpaper_scroll_to_top_padding',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_scroll_to_top_padding',array(
    'label' => __('Icon Top Bottom Padding','wall-decor-wallpaper'),
    'description' => __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
    'input_attrs' => array(
      'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
    ),
    'section'=> 'wall_decor_wallpaper_footer',
    'type'=> 'text'
  ));

  $wp_customize->add_setting('wall_decor_wallpaper_scroll_to_top_width',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_scroll_to_top_width',array(
    'label' => __('Icon Width','wall-decor-wallpaper'),
    'description' => __('Enter a value in pixels Example:20px','wall-decor-wallpaper'),
    'input_attrs' => array(
      'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
  ),
  'section'=> 'wall_decor_wallpaper_footer',
  'type'=> 'text'
  ));

  $wp_customize->add_setting('wall_decor_wallpaper_scroll_to_top_height',array(
    'default'=> '',
    'sanitize_callback' => 'sanitize_text_field'
  ));
  $wp_customize->add_control('wall_decor_wallpaper_scroll_to_top_height',array(
    'label' => __('Icon Height','wall-decor-wallpaper'),
    'description' => __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
    'input_attrs' => array(
      'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
    ),
    'section'=> 'wall_decor_wallpaper_footer',
    'type'=> 'text'
  ));

  $wp_customize->add_setting( 'wall_decor_wallpaper_scroll_to_top_border_radius', array(
    'default'              => '',
    'transport'        => 'refresh',
    'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
  ) );
  $wp_customize->add_control( 'wall_decor_wallpaper_scroll_to_top_border_radius', array(
    'label'       => esc_html__( 'Icon Border Radius','wall-decor-wallpaper' ),
    'section'     => 'wall_decor_wallpaper_footer',
    'type'        => 'range',
    'input_attrs' => array(
      'step'             => 1,
      'min'              => 1,
      'max'              => 50,
    ),
  ) );

  $wp_customize->add_setting('wall_decor_wallpaper_scroll_top_alignment',array(
    'default' => 'Right',
    'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Image_Radio_Control($wp_customize, 'wall_decor_wallpaper_scroll_top_alignment', array(
    'type' => 'select',
    'label' => esc_html__('Scroll To Top','wall-decor-wallpaper'),
    'section' => 'wall_decor_wallpaper_footer',
    'settings' => 'wall_decor_wallpaper_scroll_top_alignment',
    'choices' => array(
        'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
        'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
        'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));

	//Blog Post
	$wp_customize->add_panel( 'wall_decor_wallpaper_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'wall-decor-wallpaper' ),
		'panel' => 'wall_decor_wallpaper_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'wall_decor_wallpaper_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'wall-decor-wallpaper' ),
		'panel' => 'wall_decor_wallpaper_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('wall_decor_wallpaper_toggle_postdate', array(
		'selector' => '.post-main-box h2 a',
		'render_callback' => 'wall_decor_wallpaper_Customize_partial_wall_decor_wallpaper_toggle_postdate',
	));

	//Blog layout
    $wp_customize->add_setting('wall_decor_wallpaper_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
    ));
    $wp_customize->add_control(new Wall_Decor_Wallpaper_Image_Radio_Control($wp_customize, 'wall_decor_wallpaper_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Post Layouts','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

	$wp_customize->add_setting('wall_decor_wallpaper_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','wall-decor-wallpaper'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_post_settings',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','wall-decor-wallpaper'),
            'Right Sidebar' => esc_html__('Right Sidebar','wall-decor-wallpaper'),
            'One Column' => esc_html__('One Column','wall-decor-wallpaper'),
            'Three Columns' => __('Three Columns','wall-decor-wallpaper'),
            'Four Columns' => __('Four Columns','wall-decor-wallpaper'),
            'Grid Layout' => esc_html__('Grid Layout','wall-decor-wallpaper')
        ),
	) );

	$wp_customize->add_setting( 'wall_decor_wallpaper_blog_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_blog_postdate',array(
        'label' => esc_html__( 'Post Date','wall-decor-wallpaper' ),
        'section' => 'wall_decor_wallpaper_post_settings'
    )));

    $wp_customize->add_setting('wall_decor_wallpaper_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_post_settings',
		'setting'	=> 'wall_decor_wallpaper_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'wall_decor_wallpaper_blog_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_blog_author',array(
		'label' => esc_html__( 'Author','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_post_settings'
    )));

	$wp_customize->add_setting('wall_decor_wallpaper_toggle_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_post_settings',
		'setting'	=> 'wall_decor_wallpaper_toggle_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'wall_decor_wallpaper_blog_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_blog_comments',array(
		'label' => esc_html__( 'Comments','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_post_settings'
    )));

    $wp_customize->add_setting('wall_decor_wallpaper_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_post_settings',
		'setting'	=> 'wall_decor_wallpaper_toggle_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'wall_decor_wallpaper_blog_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_blog_time',array(
		'label' => esc_html__( 'Time','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_post_settings'
    )));

    $wp_customize->add_setting('wall_decor_wallpaper_toggle_time_icon',array(
		'default'	=> 'fas fa-clock', 
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_post_settings',
		'setting'	=> 'wall_decor_wallpaper_toggle_time_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'wall_decor_wallpaper_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_post_settings'
    )));

    $wp_customize->add_setting( 'wall_decor_wallpaper_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'wall_decor_wallpaper_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

    $wp_customize->add_setting( 'wall_decor_wallpaper_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_toggle_tags', array(
		'label' => esc_html__( 'Tags','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_post_settings'
    )));

	//Featured Image
	$wp_customize->add_setting('wall_decor_wallpaper_blog_post_featured_image_dimension',array(
       'default' => 'default',
       'sanitize_callback'	=> 'wall_decor_wallpaper_sanitize_choices'
	));
  	$wp_customize->add_control('wall_decor_wallpaper_blog_post_featured_image_dimension',array(
		'type' => 'select',
		'label'	=> __('Blog Post Featured Image Dimension','wall-decor-wallpaper'),
		'section'	=> 'wall_decor_wallpaper_post_settings',
		'choices' => array(
		'default' => __('Default','wall-decor-wallpaper'),
		'custom' => __('Custom Image Size','wall-decor-wallpaper'),
      ),
  	));

	$wp_customize->add_setting('wall_decor_wallpaper_blog_post_featured_image_custom_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('wall_decor_wallpaper_blog_post_featured_image_custom_width',array(
		'label'	=> __('Featured Image Custom Width','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'wall-decor-wallpaper' ),),
		'section'=> 'wall_decor_wallpaper_post_settings',
		'type'=> 'text',
		'active_callback' => 'wall_decor_wallpaper_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('wall_decor_wallpaper_blog_post_featured_image_custom_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_blog_post_featured_image_custom_height',array(
		'label'	=> __('Featured Image Custom Height','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'wall-decor-wallpaper' ),),
		'section'=> 'wall_decor_wallpaper_post_settings',
		'type'=> 'text',
		'active_callback' => 'wall_decor_wallpaper_blog_post_featured_image_dimension'
	));

    $wp_customize->add_setting( 'wall_decor_wallpaper_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_post_settings',
		'type'        => 'range',
		'settings'    => 'wall_decor_wallpaper_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('wall_decor_wallpaper_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','wall-decor-wallpaper'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('wall_decor_wallpaper_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','wall-decor-wallpaper'),
            'Excerpt' => esc_html__('Excerpt','wall-decor-wallpaper'),
            'No Content' => esc_html__('No Content','wall-decor-wallpaper')
        ),
	) );

	$wp_customize->add_setting('wall_decor_wallpaper_excerpt_suffix',array(
		'default'=> '[...]',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('wall_decor_wallpaper_blog_page_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_blog_page_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Blog Posts','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_post_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','wall-decor-wallpaper'),
            'Without Blocks' => __('Without Blocks','wall-decor-wallpaper')
        ),
	) );

	$wp_customize->add_setting( 'wall_decor_wallpaper_blog_pagination_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new wall_decor_wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_blog_pagination_hide_show',array(
      'label' => esc_html__( 'Show / Hide Blog Pagination','wall-decor-wallpaper' ),
      'section' => 'wall_decor_wallpaper_post_settings'
    )));

	$wp_customize->add_setting( 'wall_decor_wallpaper_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'wall_decor_wallpaper_sanitize_choices'
    ));
    $wp_customize->add_control( 'wall_decor_wallpaper_blog_pagination_type', array(
        'section' => 'wall_decor_wallpaper_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'wall-decor-wallpaper' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'wall-decor-wallpaper' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'wall-decor-wallpaper' ),
    )));

    // Button Settings
	$wp_customize->add_section( 'wall_decor_wallpaper_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'wall-decor-wallpaper' ),
		'panel' => 'wall_decor_wallpaper_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('wall_decor_wallpaper_button_text', array(
		'selector' => '.post-main-box .more-btn a',
		'render_callback' => 'wall_decor_wallpaper_Customize_partial_wall_decor_wallpaper_button_text',
	));

    $wp_customize->add_setting('wall_decor_wallpaper_button_text',array(
		'default'=> esc_html__('Read More','wall-decor-wallpaper'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_button_text',array(
		'label'	=> esc_html__('Add Button Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('wall_decor_wallpaper_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_button_font_size',array(
		'label'	=> __('Button Font Size','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'wall_decor_wallpaper_button_settings',
	));


	$wp_customize->add_setting( 'wall_decor_wallpaper_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	// button padding
	$wp_customize->add_setting('wall_decor_wallpaper_button_top_bottom_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_button_top_bottom_padding',array(
		'label'	=> __('Button Top Bottom Padding','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
    ),
		'section'=> 'wall_decor_wallpaper_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_button_left_right_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_button_left_right_padding',array(
		'label'	=> __('Button Left Right Padding','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
    ),
		'section'=> 'wall_decor_wallpaper_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'wall_decor_wallpaper_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('wall_decor_wallpaper_button_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','wall-decor-wallpaper'),
		'choices' => array(
      'Uppercase' => __('Uppercase','wall-decor-wallpaper'),
      'Capitalize' => __('Capitalize','wall-decor-wallpaper'),
      'Lowercase' => __('Lowercase','wall-decor-wallpaper'),
    ),
		'section'=> 'wall_decor_wallpaper_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'wall_decor_wallpaper_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'wall-decor-wallpaper' ),
		'panel' => 'wall_decor_wallpaper_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('wall_decor_wallpaper_related_post_title', array(
		'selector' => '.related-post h3',
		'render_callback' => 'wall_decor_wallpaper_Customize_partial_wall_decor_wallpaper_related_post_title',
	));

    $wp_customize->add_setting( 'wall_decor_wallpaper_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_related_post',array(
		'label' => esc_html__( 'Related Post','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_related_posts_settings'
    )));

    $wp_customize->add_setting('wall_decor_wallpaper_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('wall_decor_wallpaper_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'wall_decor_wallpaper_sanitize_number_absint'
	));
	$wp_customize->add_control('wall_decor_wallpaper_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'wall_decor_wallpaper_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'wall_decor_wallpaper_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'wall_decor_wallpaper_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'wall-decor-wallpaper' ),
		'panel' => 'wall_decor_wallpaper_blog_post_parent_panel',
	));

  	$wp_customize->add_setting('wall_decor_wallpaper_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_single_blog_settings',
		'setting'	=> 'wall_decor_wallpaper_single_postdate_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'wall_decor_wallpaper_toggle_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	) );
	$wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_toggle_postdate',array(
	    'label' => esc_html__( 'Show / Hide Date','wall-decor-wallpaper' ),
	   'section' => 'wall_decor_wallpaper_single_blog_settings'
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_single_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_single_author_icon',array(
		'label'	=> __('Add Author Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_single_blog_settings',
		'setting'	=> 'wall_decor_wallpaper_single_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'wall_decor_wallpaper_toggle_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	) );
	$wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_toggle_author',array(
	    'label' => esc_html__( 'Show / Hide Author','wall-decor-wallpaper' ),
	    'section' => 'wall_decor_wallpaper_single_blog_settings'
	)));

   	$wp_customize->add_setting('wall_decor_wallpaper_single_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_single_blog_settings',
		'setting'	=> 'wall_decor_wallpaper_single_comments_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'wall_decor_wallpaper_toggle_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	) );
	$wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_toggle_comments',array(
	    'label' => esc_html__( 'Show / Hide Comments','wall-decor-wallpaper' ),
	    'section' => 'wall_decor_wallpaper_single_blog_settings'
	)));

  	$wp_customize->add_setting('wall_decor_wallpaper_single_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_single_time_icon',array(
		'label'	=> __('Add Time Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_single_blog_settings',
		'setting'	=> 'wall_decor_wallpaper_single_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'wall_decor_wallpaper_toggle_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	) );
	$wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_toggle_time',array(
	    'label' => esc_html__( 'Show / Hide Time','wall-decor-wallpaper' ),
	    'section' => 'wall_decor_wallpaper_single_blog_settings'
	)));

	$wp_customize->add_setting( 'wall_decor_wallpaper_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_single_blog_settings'
    )));

	$wp_customize->add_setting( 'wall_decor_wallpaper_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
 	 $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Breadcrumb','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_single_blog_settings'
    )));

	// Single Posts Category
 	 $wp_customize->add_setting( 'wall_decor_wallpaper_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Category','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_single_blog_settings'
    )));

	$wp_customize->add_setting('wall_decor_wallpaper_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','wall-decor-wallpaper'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'wall_decor_wallpaper_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
	));
	$wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_single_blog_post_navigation_show_hide', array(
		  'label' => esc_html__( 'Show / Hide Post Navigation','wall-decor-wallpaper' ),
		  'section' => 'wall_decor_wallpaper_single_blog_settings'
	)));

	//navigation text
	$wp_customize->add_setting('wall_decor_wallpaper_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_single_blog_next_navigation_text',array(
		'default'=> 'NEXT',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_single_blog_comment_title',array(
		'default'=> 'Leave a Reply',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('wall_decor_wallpaper_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','wall-decor-wallpaper'),
		'input_attrs' => array(
        'placeholder' => __( 'Leave a Reply', 'wall-decor-wallpaper' ),
    	),
		'section'=> 'wall_decor_wallpaper_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_single_blog_comment_button_text',array(
		'default'=> 'Post Comment',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('wall_decor_wallpaper_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','wall-decor-wallpaper'),
		'input_attrs' => array(
        'placeholder' => __( 'Post Comment', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_single_blog_settings',
		'type'=> 'text'
	)); 

	$wp_customize->add_setting('wall_decor_wallpaper_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in %. Example:50%','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_single_blog_settings',
		'type'=> 'text'
	));

	 // Grid layout setting
	$wp_customize->add_section( 'wall_decor_wallpaper_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'wall-decor-wallpaper' ),
		'panel' => 'wall_decor_wallpaper_blog_post_parent_panel',
	));

  	$wp_customize->add_setting('wall_decor_wallpaper_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_grid_layout_settings',
		'setting'	=> 'wall_decor_wallpaper_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'wall_decor_wallpaper_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_grid_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','wall-decor-wallpaper' ),
        'section' => 'wall_decor_wallpaper_grid_layout_settings'
    )));

	$wp_customize->add_setting('wall_decor_wallpaper_grid_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_grid_author_icon',array(
		'label'	=> __('Add Author Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_grid_layout_settings',
		'setting'	=> 'wall_decor_wallpaper_grid_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'wall_decor_wallpaper_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_grid_layout_settings'
    )));

    $wp_customize->add_setting('wall_decor_wallpaper_grid_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_grid_layout_settings',
		'setting'	=> 'wall_decor_wallpaper_grid_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'wall_decor_wallpaper_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_grid_layout_settings'
    )));

 	$wp_customize->add_setting('wall_decor_wallpaper_grid_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_grid_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','wall-decor-wallpaper'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','wall-decor-wallpaper'),
		'section'=> 'wall_decor_wallpaper_grid_layout_settings',
		'type'=> 'text'
	));

	 $wp_customize->add_setting( 'wall_decor_wallpaper_grid_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_grid_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_grid_layout_settings',
		'type'        => 'range',
		'settings'    => 'wall_decor_wallpaper_grid_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

  	$wp_customize->add_setting('wall_decor_wallpaper_grid_button_text',array(
		'default'=> esc_html__('Read More','wall-decor-wallpaper'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_grid_layout_settings',
		'type'=> 'text'
	)); 

  	$wp_customize->add_setting('wall_decor_wallpaper_grid_button_text',array(
		'default'=> esc_html__('Read More','wall-decor-wallpaper'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_display_grid_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_display_grid_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Grid Posts','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_grid_layout_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','wall-decor-wallpaper'),
            'Without Blocks' => __('Without Blocks','wall-decor-wallpaper')
        ),
	) );

    $wp_customize->add_setting('wall_decor_wallpaper_grid_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_grid_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Grid Post Content','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_grid_layout_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','wall-decor-wallpaper'),
            'Excerpt' => esc_html__('Excerpt','wall-decor-wallpaper'),
            'No Content' => esc_html__('No Content','wall-decor-wallpaper')
        ),
	) );

    $wp_customize->add_setting( 'wall_decor_wallpaper_grid_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_grid_featured_image_border_radius', array(
		'label'       => esc_html__( 'Grid Featured Image Border Radius','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_grid_layout_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'wall_decor_wallpaper_grid_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_grid_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Grid Featured Image Box Shadow','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_grid_layout_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );
	//Other
	$wp_customize->add_panel( 'wall_decor_wallpaper_other_parent_panel', array(
		'title' => esc_html__( 'Other Settings', 'wall-decor-wallpaper' ),
		'panel' => 'wall_decor_wallpaper_panel_id',
		'priority' => 20,
	));

	// Layout
	$wp_customize->add_section( 'wall_decor_wallpaper_left_right', array(
    	'title' => esc_html__('General Settings', 'wall-decor-wallpaper'),
		'panel' => 'wall_decor_wallpaper_other_parent_panel'
	) );

	$wp_customize->add_setting('wall_decor_wallpaper_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Image_Radio_Control($wp_customize, 'wall_decor_wallpaper_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','wall-decor-wallpaper'),
        'description' => esc_html__('Here you can change the width layout of Website.','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('wall_decor_wallpaper_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','wall-decor-wallpaper'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','wall-decor-wallpaper'),
            'Right_Sidebar' => esc_html__('Right Sidebar','wall-decor-wallpaper'),
            'One_Column' => esc_html__('One Column','wall-decor-wallpaper')
        ),
	) );

	 //Wow Animation
	$wp_customize->add_setting( 'wall_decor_wallpaper_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_animation',array(
        'label' => esc_html__( 'Show / Hide Animation ','wall-decor-wallpaper' ),
        'description' => __('Here you can disable overall site animation effect','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_left_right'
    )));

	$wp_customize->add_setting( 'wall_decor_wallpaper_single_page_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_left_right'
  	)));

    // Pre-Loader
	$wp_customize->add_setting( 'wall_decor_wallpaper_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','wall-decor-wallpaper' ),
        'section' => 'wall_decor_wallpaper_left_right'
    )));

	$wp_customize->add_setting('wall_decor_wallpaper_preloader_bg_color', array(
		'default'           => '#d9a95b',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'wall-decor-wallpaper'),
		'section'  => 'wall_decor_wallpaper_left_right',
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'wall-decor-wallpaper'),
		'section'  => 'wall_decor_wallpaper_left_right',
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'wall_decor_wallpaper_preloader_bg_img',array(
        'label' => __('Preloader Background Image','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_left_right'
	)));

    //404 Page Setting
	$wp_customize->add_section('wall_decor_wallpaper_404_page',array(
		'title'	=> __('404 Page Settings','wall-decor-wallpaper'),
		'panel' => 'wall_decor_wallpaper_other_parent_panel',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('wall_decor_wallpaper_404_page_title',array(
		'label'	=> __('Add Title','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('wall_decor_wallpaper_404_page_content',array(
		'label'	=> __('Add Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_404_page_button_text',array(
		'label'	=> __('Add Button Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( 'GO BACK', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_404_page',
		'type'=> 'text'
	));

	//No Result Page Setting
	$wp_customize->add_section('wall_decor_wallpaper_no_results_page',array(
		'title'	=> __('No Results Page Settings','wall-decor-wallpaper'),
		'panel' => 'wall_decor_wallpaper_other_parent_panel',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('wall_decor_wallpaper_no_results_page_title',array(
		'label'	=> __('Add Title','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('wall_decor_wallpaper_no_results_page_content',array(
		'label'	=> __('Add Text','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_no_results_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('wall_decor_wallpaper_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','wall-decor-wallpaper'),
		'panel' => 'wall_decor_wallpaper_other_parent_panel',
	));

	$wp_customize->add_setting('wall_decor_wallpaper_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_social_icon_padding',array(
		'label'	=> __('Icon Padding','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_social_icon_width',array(
		'label'	=> __('Icon Width','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_social_icon_height',array(
		'label'	=> __('Icon Height','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_social_icon_settings',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('wall_decor_wallpaper_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','wall-decor-wallpaper'),
		'panel' => 'wall_decor_wallpaper_other_parent_panel',
	));

    $wp_customize->add_setting( 'wall_decor_wallpaper_resp_slider_hide_show',array(
      	'default' => 1,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','wall-decor-wallpaper' ),
      	'section' => 'wall_decor_wallpaper_responsive_media'
    )));

    $wp_customize->add_setting( 'wall_decor_wallpaper_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','wall-decor-wallpaper' ),
      	'section' => 'wall_decor_wallpaper_responsive_media'
    )));

    $wp_customize->add_setting( 'wall_decor_wallpaper_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ));
    $wp_customize->add_control( new Wall_Decor_Wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','wall-decor-wallpaper' ),
      	'section' => 'wall_decor_wallpaper_responsive_media'
    )));

    $wp_customize->add_setting('wall_decor_wallpaper_resp_menu_toggle_btn_bg_color', array(
		'default'           => '#d9a95b',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'wall_decor_wallpaper_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'wall-decor-wallpaper'),
		'section'  => 'wall_decor_wallpaper_responsive_media',
	)));

    $wp_customize->add_setting('wall_decor_wallpaper_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_responsive_media',
		'setting'	=> 'wall_decor_wallpaper_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('wall_decor_wallpaper_res_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Wall_Decor_Wallpaper_Fontawesome_Icon_Chooser(
        $wp_customize,'wall_decor_wallpaper_res_close_menu_icon',array(
		'label'	=> __('Add Close Menu Icon','wall-decor-wallpaper'),
		'transport' => 'refresh',
		'section'	=> 'wall_decor_wallpaper_responsive_media',
		'setting'	=> 'wall_decor_wallpaper_res_close_menu_icon',
		'type'		=> 'icon'
	)));

   //Woocommerce settings
	$wp_customize->add_section('wall_decor_wallpaper_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'wall-decor-wallpaper'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'wall_decor_wallpaper_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new wall_decor_wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Shop Page Sidebar','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_woocommerce_section'
    )));

    $wp_customize->add_setting('wall_decor_wallpaper_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','wall-decor-wallpaper'),
            'Right Sidebar' => __('Right Sidebar','wall-decor-wallpaper'),
        ),
	) );

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'wall_decor_wallpaper_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar',
		'render_callback' => 'wall_decor_wallpaper_customize_partial_wall_decor_wallpaper_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'wall_decor_wallpaper_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new wall_decor_wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Single Product Sidebar','wall-decor-wallpaper' ),
		'section' => 'wall_decor_wallpaper_woocommerce_section'
    )));

       $wp_customize->add_setting('wall_decor_wallpaper_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','wall-decor-wallpaper'),
            'Right Sidebar' => __('Right Sidebar','wall-decor-wallpaper'),
        ),
	) );

	//Products padding
	$wp_customize->add_setting('wall_decor_wallpaper_products_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_products_padding_top_bottom',array(
		'label'	=> __('Products Padding Top Bottom','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_products_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_products_padding_left_right',array(
		'label'	=> __('Products Padding Left Right','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_woocommerce_section',
		'type'=> 'text'
	));

	//Products box shadow
	$wp_customize->add_setting( 'wall_decor_wallpaper_products_box_shadow', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_products_box_shadow', array(
		'label'       => esc_html__( 'Products Box Shadow','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products border radius
    $wp_customize->add_setting( 'wall_decor_wallpaper_products_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_products_border_radius', array(
		'label'       => esc_html__( 'Products Border Radius','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('wall_decor_wallpaper_products_btn_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_products_btn_padding_top_bottom',array(
		'label'	=> __('Products Button Padding Top Bottom','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_products_btn_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_products_btn_padding_left_right',array(
		'label'	=> __('Products Button Padding Left Right','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'wall_decor_wallpaper_products_button_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_products_button_border_radius', array(
		'label'       => esc_html__( 'Products Button Border Radius','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products Sale Badge
	$wp_customize->add_setting('wall_decor_wallpaper_woocommerce_sale_position',array(
        'default' => 'right',
        'sanitize_callback' => 'wall_decor_wallpaper_sanitize_choices'
	));
	$wp_customize->add_control('wall_decor_wallpaper_woocommerce_sale_position',array(
        'type' => 'select',
        'label' => __('Sale Badge Position','wall-decor-wallpaper'),
        'section' => 'wall_decor_wallpaper_woocommerce_section',
        'choices' => array(
            'left' => __('Left','wall-decor-wallpaper'),
            'right' => __('Right','wall-decor-wallpaper'),
        ),
	) );

	$wp_customize->add_setting('wall_decor_wallpaper_woocommerce_sale_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_woocommerce_sale_font_size',array(
		'label'	=> __('Sale Font Size','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_woocommerce_sale_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_woocommerce_sale_padding_top_bottom',array(
		'label'	=> __('Sale Padding Top Bottom','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('wall_decor_wallpaper_woocommerce_sale_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('wall_decor_wallpaper_woocommerce_sale_padding_left_right',array(
		'label'	=> __('Sale Padding Left Right','wall-decor-wallpaper'),
		'description'	=> __('Enter a value in pixels. Example:20px','wall-decor-wallpaper'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'wall-decor-wallpaper' ),
        ),
		'section'=> 'wall_decor_wallpaper_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'wall_decor_wallpaper_woocommerce_sale_border_radius', array(
		'default'              => '100',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'wall_decor_wallpaper_sanitize_number_range'
	) );
	$wp_customize->add_control( 'wall_decor_wallpaper_woocommerce_sale_border_radius', array(
		'label'       => esc_html__( 'Sale Border Radius','wall-decor-wallpaper' ),
		'section'     => 'wall_decor_wallpaper_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

    //Related Products
	$wp_customize->add_setting( 'wall_decor_wallpaper_related_product_show_hide',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'wall_decor_wallpaper_switch_sanitization'
    ) );
    $wp_customize->add_control( new wall_decor_wallpaper_Toggle_Switch_Custom_Control( $wp_customize, 'wall_decor_wallpaper_related_product_show_hide',array(
        'label' => esc_html__( 'Show / Hide Related product','wall-decor-wallpaper' ),
        'section' => 'wall_decor_wallpaper_woocommerce_section'
    )));

}

add_action( 'customize_register', 'wall_decor_wallpaper_customize_register' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Wall_Decor_Wallpaper_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Wall_Decor_Wallpaper_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Wall_Decor_Wallpaper_Customize_Section_Pro( $manager,'wall_decor_wallpaper_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'WALL DECOR PRO', 'wall-decor-wallpaper' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'wall-decor-wallpaper' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/wall-decor-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new Wall_Decor_Wallpaper_Customize_Section_Pro($manager,'wall_decor_wallpaper_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'wall-decor-wallpaper' ),
			'pro_text' => esc_html__( 'DOCS', 'wall-decor-wallpaper' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-wall-decor-wallpaper/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'wall-decor-wallpaper-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'wall-decor-wallpaper-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Wall_Decor_Wallpaper_Customize::get_instance();
